@@ -5,7 +5,7 @@
 # Author    : Chris Jones
 # Email     : crj341@student.bham.ac.uk
 # Date      : 26/06/2020
-# Version   : 0.3.31
+# Version   : 0.3.32
 
 from operator import contains
 import  numpy                   as      np
@@ -1705,7 +1705,7 @@ class AFM:
                 plt_data = snap_dist
             elif plot == 'work':
                 plt_title = 'Work of adhesion (J)'
-                plt_data = snap_dist
+                plt_data = work
 
             if topography_3d == False:
 
@@ -1723,8 +1723,8 @@ class AFM:
                             x = x_pos,
                             y = y_pos,
                             z = plt_data,
-                            cmin = cmin,
-                            cmax = cmax,
+                            zmin = cmin,
+                            zmax = cmax,
                             type = 'heatmap',
                             colorscale = 'YlOrBr',
                             colorbar=dict(title=plt_title)
